import React, { Component } from 'react';
import PropTypes from 'prop-types';
import {
  addCommas,
  removeCommas,
  checkIsValidNumber,
  positiveIntegerOnly,
} from './utilities';

class CurrenyInputField extends Component {
  constructor(props) {
    super(props);

    this.state = {
      value: '',
      errorInput: false,
      errorLimit: false,
      errorMaxReached: false,
    };

    this.processChange = this.processChange.bind(this);
  }

  processChange(event) {
    let { value } = event.target;
    const limit = this.props.limit || 9999999999999;

    if (this.props.showPrefix) {
      value = value.replace('£', '');
    }

    if (value === '' || value === null) {
      this.setState({
        value: '',
        errorInput: false,
      });
      this.props.onChange(0);
      return false;
    }

    value = removeCommas(value);

    if (checkIsValidNumber(value)) {
      // Check if above limit
      if (value > limit) {
        this.setState({ errorInput: true });
        if (this.props.limit) {
          this.setState({ errorLimit: true });
        } else {
          this.setState({ errorMaxReached: true });
        }
      } else {
        this.setState({ errorLimit: false });
        this.setState({ errorInput: false });
        this.setState({ errorMaxReached: false });
        this.props.onChange(positiveIntegerOnly(value));

        let formattedValue = addCommas(value);

        if (this.props.showPrefix) {
          formattedValue = `£${formattedValue}`;
        }

        if (this.props.suffix) {
          formattedValue += this.props.suffix;
        }

        this.setState({ value: formattedValue });
      }
    } else {
      this.setState({ errorInput: true });
    }
    return false;
  }

  render() {
    let formGroupDanger = '';
    let inputDanger = '';
    let feedbackClass = 'hidden-xs-up';
    let { errorMessage } = this.props;

    if (this.state.errorInput) {
      formGroupDanger = 'has-danger';
      inputDanger = 'form-control-danger';
      feedbackClass = '';
    }

    if (this.state.errorLimit && this.props.limit) {
      errorMessage = `Max value is £${this.props.limit}`;
    } else if (this.state.errorMaxReached) {
      errorMessage = 'Maxium value is 9,999,999,999,999';
    }

    return (
      <div className={`form-group ${formGroupDanger}`}>
        <div>
          <label htmlFor={this.props.id} className="">{this.props.label}
            <input
              type="string"
              id={this.props.id}
              className={`form-control ${inputDanger}`}
              onChange={this.processChange}
              placeholder={this.props.placeholder}
              value={this.state.value}
            />
          </label>
          <div className={`form-control-feedback ${feedbackClass}`}>
            <small>{errorMessage}</small>
          </div>
          <small className="form-text text-muted">{this.props.description}</small>
        </div>
      </div>
    );
  }
}

CurrenyInputField.propTypes = {
  id: PropTypes.string,
  description: PropTypes.string,
  errorMessage: PropTypes.string,
  label: PropTypes.string,
  limit: PropTypes.number,
  showPrefix: PropTypes.bool,
  suffix: PropTypes.string,
  onChange: PropTypes.func,
  placeholder: PropTypes.string,
};

CurrenyInputField.defaultProps = {
  id: '',
  description: '',
  errorMessage: 'Please enter a valid number',
  label: '',
  limit: null,
  showPrefix: true,
  suffix: null,
  placeholder: '',
  onChange: () => {},
};

export default CurrenyInputField;
