import React from 'react';
import { expect } from 'chai';
import { mount, configure } from 'enzyme';
import Adapter from 'enzyme-adapter-react-16';
import setup from './setup';
import CurrencyInputField from '../src/index';

configure({ adapter: new Adapter() });

describe('<CurrencyInputField />', () => {
  before('setup dom', () => {
    setup(); // setup the jsdom
  });
  it('Renders', () => {
    const wrapper = mount(<CurrencyInputField
      onChange={() => true}
      placeholder="£100"
      label="1 .Enter a value: (Max £1000)"
      limit={1000}
      errorMessage="This is the error message"
      description="This is the description"
    />);

    expect(wrapper.html()).to.contain('Enter a value: (Max £1000)');
    expect(wrapper.html()).to.contain('This is the description');
    expect(wrapper.html()).to.contain('This is the error message');
    expect(wrapper.html()).to.contain('placeholder="£100"');
  });
  it('Displays a default error message', () => {
    const wrapper = mount(<CurrencyInputField />);
    const input = wrapper.find('.form-control');
    input.simulate('change', { target: { value: 'Hello' } });
    const errorMessage = wrapper.find('.form-control-feedback');
    expect(errorMessage.text()).to.equal('Please enter a valid number');
  });
  it('Displays a custom error message', () => {
    const wrapper = mount(<CurrencyInputField errorMessage="Custom error message" />);
    const input = wrapper.find('.form-control');
    input.simulate('change', { target: { value: 'Hello' } });
    const errorMessage = wrapper.find('.form-control-feedback');
    expect(errorMessage.text()).to.equal('Custom error message');
  });
  it('Displays a custom description', () => {
    const wrapper = mount(<CurrencyInputField description="Custom information description" />);
    const description = wrapper.find('.form-text');
    expect(description.text()).to.equal('Custom information description');
  });
  it('Accepts valid value', () => {
    const wrapper = mount(<CurrencyInputField />);
    const input = wrapper.find('.form-control');
    input.simulate('change', { target: { value: '60' } });
    expect(input.html()).to.contain('value="£60"');
  });
});
