const webpack = require('webpack');
const path = require('path');

const config = {
  entry: {
    app: [path.join(__dirname, 'example')],
  },
  output: {
    path: path.join(__dirname, 'example'),
    filename: 'bundle.js',
  },
  plugins: [
    new webpack.DefinePlugin({
      'process.env.NODE_ENV': JSON.stringify(process.env.NODE_ENV),
    }),
  ],
  resolve: {
    extensions: ['.js'],
  },
  module: {
    loaders: [
      {
        test: /\.(js|jsx)?$/,
        loaders: ['babel-loader'],
        exclude: /node_modules/,
      },
      {
        test: /\.css$/,
        use: ['style-loader', 'css-loader'],
      },
    ],
  },
};

if (process.env.NODE_ENV === 'production') {
  console.log('Building for production');
  config.devtool = 'cheap-module-source-map';
  config.plugins.push(
    new webpack.optimize.UglifyJsPlugin({
      compress: {
        screw_ie8: true,
        warnings: false,
      },
      sourceMap: false,
    }),
    new webpack.optimize.AggressiveMergingPlugin(), // Merge chunks
  );
  config.output = {
    path: path.resolve(__dirname, 'build'),
    filename: 'index.js',
  };
}

if (process.env.NODE_ENV === 'dev') {
  console.log('Building for development');
  config.devServer = {
    port: 3000,
    contentBase: path.join(__dirname, 'example'),
  };
  config.stats = {
    colors: true,
  };
  config.devtool = 'source-map';
}

module.exports = config;
